$(document).ready(function(){
    window.setTimeout(function() { 
        $(".alert").children('a').trigger('click');
    }, 2000);
});
